pub struct SetDailyWithdrawalLimitProposal { /* private fields */ }Expand description
Updates the daily withdrawal limit on the variable anchor system.
The SetDailyWithdrawalLimitProposal updates the daily withdrawal limit
amount allowed on the variable anchor system.
The format of the proposal looks like:
┌────────────────────┬───────────────────────────┐
│ │ │
│ ProposalHeader 40B │ DailyWithdrawalLimit 32B │
│ │ │
└────────────────────┴───────────────────────────┘
Implementations
sourceimpl SetDailyWithdrawalLimitProposal
impl SetDailyWithdrawalLimitProposal
sourcepub const fn new(
header: ProposalHeader,
daily_withdrawal_limit: [u8; 32]
) -> Self
pub const fn new( header: ProposalHeader, daily_withdrawal_limit: [u8; 32] ) -> Self
Creates a new proposal.
sourcepub const fn header(&self) -> ProposalHeader
pub const fn header(&self) -> ProposalHeader
Returns the header of the proposal.
sourcepub const fn daily_withdrawal_limit(&self) -> &[u8; 32]
pub const fn daily_withdrawal_limit(&self) -> &[u8; 32]
Returns a reference to that field of the proposal.