Struct webb_proposals::evm::SetNativeAllowedProposal
source · pub struct SetNativeAllowedProposal { /* private fields */ }Expand description
Set Native Allowed Proposal.
The SetNativeAllowedProposal updates the Funguible Token Wrapper
to whether or not allow native tokens to be wrapped.
The format of the proposal looks like:
┌────────────────────┬──────────────────┐
│ │ │
│ ProposalHeader 40B │ NativeAllowed 1B │
│ │ │
└────────────────────┴──────────────────┘
Implementations
sourceimpl SetNativeAllowedProposal
impl SetNativeAllowedProposal
sourcepub const fn new(header: ProposalHeader, native_allowed: bool) -> Self
pub const fn new(header: ProposalHeader, native_allowed: bool) -> Self
Creates a new proposal.
sourcepub const fn header(&self) -> ProposalHeader
pub const fn header(&self) -> ProposalHeader
Returns the header of the proposal.
sourcepub const fn native_allowed(&self) -> &bool
pub const fn native_allowed(&self) -> &bool
Returns a reference to that field of the proposal.