Struct webb_proposals::evm::TokenRemoveProposal
source · pub struct TokenRemoveProposal { /* private fields */ }Expand description
Token Remove Proposal.
Suppose a token has been allowed to be wrapped into the WEBB token by the
token add proposal. The TokenRemoveProposal can disallow this added
token from being wrapped into the WEBB token.
The format of the proposal looks like:
┌────────────────────┬──────────────────┐
│ │ │
│ ProposalHeader 40B │ TokenAddress 20B │
│ │ │
└────────────────────┴──────────────────┘
Implementations
sourceimpl TokenRemoveProposal
impl TokenRemoveProposal
sourcepub const fn new(header: ProposalHeader, token_address: [u8; 20]) -> Self
pub const fn new(header: ProposalHeader, token_address: [u8; 20]) -> Self
Creates a new proposal.
sourcepub const fn header(&self) -> ProposalHeader
pub const fn header(&self) -> ProposalHeader
Returns the header of the proposal.
sourcepub const fn token_address(&self) -> &[u8; 20]
pub const fn token_address(&self) -> &[u8; 20]
Returns a reference to that field of the proposal.